@@ -42,7 +42,7 @@ class NMEA2000Message:
         self.source_iso_name = source_iso_name
         self.hash = None
         self.raw_can_data = raw_can_data
-        
+
         if build_network_map:
             # Using MD5 as we don't need secure hashing and speed matters
             # For now, we will NOT include the ISO name in the primary key
@@ -86,16 +86,19 @@ class NMEA2000Message:
                     f.unit_of_measurement = "kts"
                     f.value = mps_to_knots(f.value)
 
-    def __repr__(self):
+    def __str__(self):
         return f"NMEA2000Message(PGN={self.PGN}, id={self.id}, pri={self.priority}, src={self.source}, source_iso_name={self.source_iso_name}, dest={self.destination}, description={self.description}, fields={self.fields})"
 
+    def __repr__(self):
+        return self.__str__()
+
     def to_string_test_style(self):
         fields_str = ', '.join([field.to_string_test_style() for field in self.fields])
         return f"{self.PGN} {self.description}: {fields_str}"
 
     def to_json(self):
         def default(obj: Any) -> Any:
-            if isinstance(obj, bytes):
+            if isinstance(obj, (bytes, bytearray)):
                 return obj.hex()
             if isinstance(obj, timedelta):
                 return obj.total_seconds()
@@ -146,9 +149,12 @@ class NMEA2000Field:
     type: FieldTypes = FieldTypes.NUMBER
     part_of_primary_key: bool | None = None
 
-    def __repr__(self):
+    def __str__(self):
         return f"NMEA2000Field(id={self.id}, name={self.name}, description={self.description}, unit_of_measurement={self.unit_of_measurement}, value={self.value}, raw_value={self.raw_value}, physical_quantities={self.physical_quantities}, type={self.type}, part_of_primary_key = {self.part_of_primary_key})"
 
+    def __repr__(self):
+        return self.__str__()
+    
     def to_string_test_style(self):
         if isinstance(self.raw_value, int):
             # Convert integer to bytes (big-endian)
@@ -207,7 +213,7 @@ class IsoName:
         self.industry_group = message.get_field_str_value_by_id('industryGroup')
         self.arbitrary_address_capable = message.get_field_str_value_by_id('arbitraryAddressCapable') == "Yes"
 
-    def __repr__(self):
+    def __str__(self) -> str:
         return (
             f"IsoName(unique_number={self.unique_number}, "
             f"manufacturer_code='{self.manufacturer_code}', "
@@ -218,4 +224,7 @@ class IsoName:
             f"industry_group='{self.industry_group}', "
             f"arbitrary_address_capable={self.arbitrary_address_capable}, "
             f"name={self.name})"
-        )
\ No newline at end of file
+        )
+    
+    def __repr__(self):
+        return self.__str__()
\ No newline at end of file
